/*
Description: This widget generates a list of cards that can be useful when the user wants
a card that has an icon on the left top and information on other parts of the card.
The left side has an icon at the top and a widget placeholder at the bottom.
The right side has three widget placeholders at top, middle and bottom.

Imports:
import 'package:flutter_svg/svg.dart';
import 'package:flutter_widgets_library/theme/color.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-LeftThumbnailCard.dart';

Usage:
The widget accepts a list of card objects of the CardWithLeftThumbnailData class.
It returns a collection of cards. This collection can be received by the user for any widget that
uses 'children' property like a GridView, PageView, Column etc.

//Defining card objects
List<CardWithLeftThumbnailData> cards = [];

    CardWithLeftThumbnailData thumbnailCardData = new CardWithLeftThumbnailData(
        cardBackgroundColor: SalesforceColor.orange,
        borderRadius: 6,
        shadow: false,
        shadowColor: SalesforceColor.black,
        shadowRadius: 2,
        heading: 'My Open Tasks',
        headingTextColor: SalesforceColor.white,
        headingTextSize: 20,
        headingTextFamily: 'Roboto',
        headingTextWeight: FontWeight.normal,
        paddingValue: 20,
        icon: Icon(Icons.list),
        iconColor: SalesforceColor.black,
        iconBackgroundColor: SalesforceColor.white,
        iconHeight: 20,
        iconWidth: 20,
        thumbnailWidth: 50,
        thumbnailHeight: 50,
        leftBottomWidget: Column(
          crossAxisAlignment: CrossAxisAlignment.end,
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            Text(
              'Count of my wins',
              style: TextStyle(
                  color: SalesforceColor.white,
                  fontSize: 12,
                  fontFamily: 'Roboto'),
            ),
            SizedBox(
              height: 5,
            ),
            Text(
              '0',
              style: TextStyle(
                  color: SalesforceColor.white,
                  fontSize: 18,
                  fontFamily: 'Roboto'),
            )
          ],
        ),
        rightBottomWidget: Column(
          crossAxisAlignment: CrossAxisAlignment.end,
          children: <Widget>[
            Text('Overdue Opps',
                style: TextStyle(
                    color: SalesforceColor.white,
                    fontSize: 12,
                    fontFamily: 'Roboto'),
                textAlign: TextAlign.right),
            SizedBox(
              height: 5,
            ),
            Text('0',
                style: TextStyle(
                  color: SalesforceColor.white,
                  fontSize: 18,
                  fontFamily: 'Roboto',
                ),
                textAlign: TextAlign.right),
          ],
        ),
        rightMiddleWidget: Column(
          crossAxisAlignment: CrossAxisAlignment.end,
          children: <Widget>[
            Text('At Risk',
                style: TextStyle(
                    color: SalesforceColor.white,
                    fontSize: 12,
                    fontFamily: 'Roboto'),
                textAlign: TextAlign.right),
            SizedBox(
              height: 5,
            ),
            Text('0',
                style: TextStyle(
                    color: SalesforceColor.white,
                    fontSize: 18,
                    fontFamily: 'Roboto'),
                textAlign: TextAlign.right),
          ],
        ));
    
    cards.add(thumbnailCardData);
// Calling the widget
  cardWithLeftThumbnail(cards) - Note: returns multiple items.

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'widget-classesUsed.dart';
//import 'package:flutter_svg/svg.dart';

List<Widget> cardWithLeftThumbnail(List<CardWithLeftThumbnailData> params) {
  List<Widget> thumbnailCards = [];

  for (var i = 0; i < params.length; i++) {
    Widget thumbnailCard = Container(
      padding: EdgeInsets.all(params[i].paddingValue),
      decoration: (params[i].shadow == true)
          ? BoxDecoration(
              boxShadow: [],
              color: params[i].cardBackgroundColor,
              borderRadius: BorderRadius.circular(params[i].borderRadius))
          : BoxDecoration(
              color: params[i].cardBackgroundColor,
              borderRadius: BorderRadius.circular(params[i].borderRadius)),
      child: Row(
          crossAxisAlignment: CrossAxisAlignment.end,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Expanded(
              flex: 0,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Container(
                    decoration: BoxDecoration(
                        color: params[i].iconBackgroundColor,
                        borderRadius:
                            BorderRadius.circular(params[i].borderRadius)),
                    padding: EdgeInsets.all(params[i].paddingValue / 2),
                    height: params[i].thumbnailHeight,
                    width: params[i].thumbnailWidth,
                    child: (params[i].icon == null)
                        ? Image.asset(
                            'images/salesforce/profile-icon.svg',
                            height: params[i].iconHeight,
                            width: params[i].iconWidth,
                          )
                        : params[i].icon,
                  ),
                  SizedBox(height: 50),
                  params[i].leftBottomWidget,
                ],
              ),
            ),
            Expanded(
              flex: 8,
              child: Padding(
                padding: const EdgeInsets.only(right: 10),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.end,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: <Widget>[
                    Text(
                      params[i].heading,
                      style: TextStyle(
                          color: params[i].headingTextColor,
                          fontSize: params[i].headingTextSize,
                          fontFamily: params[i].headingTextFamily),
                      textAlign: TextAlign.right,
                    ),
                    SizedBox(
                      height: 10,
                    ),
                    params[i].rightMiddleWidget,
                    SizedBox(height: 32),
                    params[i].rightBottomWidget
                  ],
                ),
              ),
            )
          ]),
    );
    thumbnailCards.add(thumbnailCard);
  }
  return thumbnailCards;
}
