/*
Description:
Card with an image in the background and title and subtitle in the foreground.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-TransparentCard.dart';

Usage:
-Creating the object for the card

onclickCardBtn(int nIndex, String sText) {print(nIndex);print(sText);}
    MaterialCardData Obj1 = new MaterialCardData(
        title: "Colosseum",
        subtitle: "The Colosseum in Rome was built in the first century by order of the Emperor Vespasian",
        containerHeight: 100.0,
        textStyle1: TextStyle(
          color: Colors.black,
          fontSize: 20,
          fontWeight: FontWeight.bold,
        ),
        textStyle2: TextStyle(
          color: Colors.black,
          fontSize: 16.0,
        ),
        imgHeight: 250,
        imgWidth: 250,
        imgType: "Network",
        imgPath: "https://cdn.britannica.com/75/75775-050-1FC4B34B/Colosseum-Rome.jpg");


    -Object call for the widget
        body: imageCardWidget(Obj1, onclickCardBtn),


*/

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';
import 'theme.dart';

Widget imageCardWidget(
    MaterialCardData data, void Function(int, String) callback) {
  ImageProvider image;
  if(data.imgType == "Network"){
    image=NetworkImage(data.imgPath);
  }
  else{
    image=AssetImage(data.imgPath);
  }
  return Container(
      height: (data.imgHeight != null) ? data.imgHeight : constants.heightTwoHundred,
      width: (data.imgWidth != null) ? data.imgWidth : constants.heightTwoHundred,
  child: Stack(
    children: <Widget>[
      Container(
        decoration: BoxDecoration(
          image: (data.containerDecoration != null) ? data.containerDecoration : DecorationImage(
            colorFilter: new ColorFilter.mode((mediumGreyThemeData().accentColor).withOpacity(constants.opacity), BlendMode.lighten),
            image: (image != null) ? image : NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png"),
            fit: BoxFit.cover,
          ),
          borderRadius: BorderRadius.all(Radius.circular(constants.twentyPixelDouble)),
        ),
      ),

      Column(
        mainAxisAlignment: MainAxisAlignment.end,
        children: <Widget>[
          Container(
            child: Container(
              height: (data.containerHeight != null) ? data.containerHeight : constants.containerheight,
              child: Opacity(
                opacity: (data.cardOpacity != null) ? data.cardOpacity : constants.opacityCard,
                child: Card(
                  color: (data.cardbgColor != null) ? data.cardbgColor : mediumGreyThemeData().backgroundColor,
                  margin: EdgeInsets.all((data.margin1 != null) ? data.margin1 : constants.heightTwenty - constants.heightThree),
                  elevation: (data.elevation != null) ? data.elevation : constants.elevation,
                  child: Padding(
                    padding: EdgeInsets.all((data.padding1 != null) ? data.padding1 : constants.heightTen),
                    child: Column(
                      children: <Widget>[
                        Center(
                          child: Text((data.title != null) ? data.title : constants.cardTitle, overflow: TextOverflow.ellipsis,
                            textAlign: TextAlign.center,
                            style: (data.textStyle1 != null) ? data.textStyle1 : TextStyle(color:mediumGreyThemeData().accentColor,
                              fontWeight: constants.fontBold,
                              fontSize: constants.heightTwenty,),),
                        ),
                        Center(
                          child: Text((data.subtitle != null) ? data.subtitle : constants.cardSubtitle ,overflow: TextOverflow.ellipsis,
                            textAlign: TextAlign.center,
                            style: (data.textStyle2 != null) ? data.textStyle2 : TextStyle(color:Colors.white,
                                fontStyle: FontStyle.italic,
                                fontSize: constants.heightTwenty
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              ),
            ),
          ),
        ],
      ),
    ],

  )
  );

}
