/*
Description:
A widget that dynamically creates a vertical tab along with a vertical tab view for each tab.
This is an alternate to the normal horizontal tab view and becomes useful in some scenarios.


Usage:
The user can pass in a list of VTabBarProducts which is our custom class which has a tab name, an icon and the widget to be displayed inside the yab bar view.
The user can also pass on parameters like shadow elevation, tab width, selector color etc.
See VTabBarProducts and VerticalSheetParameters class definitons for more information.
The user also passes a callback function which is invoked when a tab is Tapped.
- The widget returns the index value and the title of that particular tab.

The user has to create an object of List<VTabBarProducts>(vtabs), a callback function and an object of VerticalSheetParameters(paramobj).

onClickCallback(int nIndex, String sText) {
      print(nIndex);
      print(sText);}
    CustomVerticalTabParameters paramobj = new CustomVerticalTabParameters(
        itemExtent: 150,
        tabsWidth: 100,
        selectedTabBackgroundColor: Colors.red,
        unselectedTabBackgroundColor: Colors.grey,
        dividerColor:Colors.black,
        tabsShadowColor:Colors.black,
        tabsElevation: 10,
        indicatorColor: Colors.black54,
        changePageDuration: Duration(seconds: 2),
        changePageCurve: Curves.easeInOut,
        iconColor: Colors.white);
    List<VTabBarProducts> vtabs = [];
    VTabBarProducts vtab1 = new VTabBarProducts(
        "text1" ,
        Icons.credit_card,
        Container(
          child: Text("tab1"), )
    );
    VTabBarProducts vtab2 = new VTabBarProducts(
        "text2" ,
        Icons.credit_card, Container(
      child: Text("tabb2"), )
    );
    vtabs.add(vtab1);
    vtabs.add(vtab2);


VerticalTabs(tabsInfo: vtabs, verticalTabCallback: onClickCallback, params: paramobj,)

imports: 
import 'package:flutter/material.dart';
import 'theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-VerticalTabs.dart';

Author:
Anubhav Sinha
*/


import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';


class VerticalTabs extends StatefulWidget {
  final Key key;
  final CustomVerticalTabParameters params;
  final List<VTabBarProducts> tabsInfo;
  final Function(int, String) verticalTabCallback;

  VerticalTabs(
      {this.key,
        @required this.tabsInfo,
        this.verticalTabCallback,
        this.params
        })
      :
        super(key: key);
  @override
  _VerticalTabsState createState() => _VerticalTabsState(
      this.tabsInfo,
    this.verticalTabCallback,
    this.params
  );
}
class _VerticalTabsState extends State<VerticalTabs>
    with TickerProviderStateMixin {
  int _selectedIndex = cons.zero;
  bool _changePageByTapView;
  AnimationController animationController;
  Animation<double> animation;
  Animation<RelativeRect> rectAnimation;
  PageController pageController = PageController();
  List<AnimationController> animationControllers = [];
  ScrollPhysics pageScrollPhysics = AlwaysScrollableScrollPhysics();
  List<VTabBarProducts> tabsInfo;
  Function(int, String) verticalTabCallback;
  CustomVerticalTabParameters params;

  _VerticalTabsState(
      List<VTabBarProducts> tabsInfo,
      Function(int, String) verticalTabCallback,
      CustomVerticalTabParameters params
      ){
    this.tabsInfo = tabsInfo;
    this.verticalTabCallback = verticalTabCallback;
    this.params = params;
  }
  @override
  void initState() {
    for (int i = 0; i < widget.tabsInfo.length; i++) {
      animationControllers.add(AnimationController(
        duration: const Duration(milliseconds: cons.durationTwo),
        vsync: this,
      ));
    }
    _selectTab(0);
      pageScrollPhysics = NeverScrollableScrollPhysics();
    super.initState();
  }
  @override
  Widget build(BuildContext context) {

if(params != null){    
    List<Tab> tabs = [];
    List<Widget> wid = [];
    List<ListItems> prodContainer = [];
    for (int tabCount = 0; tabCount < tabsInfo.length; tabCount++) {
      prodContainer.add(
          new ListItems(tabsInfo[tabCount].icons, tabsInfo[tabCount].text));
    }
    var tabx;
    for (var counter = 0; counter < tabsInfo.length; counter++) {
      tabx = new Tab(
          text: tabsInfo[counter].text,  
          icon: Icon(tabsInfo[counter].icons, color: (params.iconColor != null)? params.iconColor: Theme.of(context).indicatorColor) != null
              ? Icon(tabsInfo[counter].icons, color: (params.iconColor != null)? params.iconColor: Theme.of(context).indicatorColor)
              : Icon(Icons.favorite),
              );
      tabs.add(tabx);
    }
    for (var i = 0; i < tabsInfo.length; i++) {
      tabx = tabsInfo[i].widget;
      wid.add(tabx);
    }

    return Directionality(
      textDirection: (params.direction!= null)? params.direction: TextDirection.ltr,
      child: Column(
        children: <Widget>[
          Expanded(
            child: Row(
              children: <Widget>[
                Material(
                  child: Container(
                    width: (params.tabsWidth != null)? params.tabsWidth: cons.heightHundred,
                    color: (params.unselectedTabBackgroundColor!= null)? params.unselectedTabBackgroundColor: Theme.of(context).disabledColor ,
                    child: ListView.builder(
                      itemExtent: (params.itemExtent != null)? params.itemExtent: cons.heightHundred + cons.heightSixty,
                      itemCount: tabsInfo.length,
                      itemBuilder: (context, index) {
                        Tab tab = tabs[index];
                        Alignment alignment = Alignment.centerLeft;
                        if (params.direction == TextDirection.rtl) {
                          alignment = Alignment.centerRight;
                        }
                        Widget child;
                        if (tab.child != null) {
                          child = tab.child;
                        } else {
                          child = Row(
                            children: <Widget>[
                              (tab.icon != null)
                                  ? Row(
                                children: <Widget>[
                                  tab.icon,
                                  SizedBox(
                                    width: cons.heightFive,
                                  )
                                ],
                              )
                                  : Container(),
                              (tab.text != null) ? Text(tab.text) : Container(),
                            ],
                          );
                        }
                        Color itemBGColor = (params.unselectedTabBackgroundColor != null)? params.unselectedTabBackgroundColor: Theme.of(context).disabledColor ;
                        if (_selectedIndex == index)
                          itemBGColor = (params.selectedTabBackgroundColor != null)? params.selectedTabBackgroundColor: Theme.of(context).selectedRowColor;
                        return GestureDetector(
                          onTap: () {
                            
                            _changePageByTapView = true;
                            setState(() {
                              _selectTab(index);
                            });
                            
                            pageController.animateToPage(index,
                                duration: (params.changePageDuration != null)? params.changePageDuration : Duration(seconds: cons.intTwo),
                                curve: (params.changePageCurve !=null)? params.changePageCurve : Curves.easeInOut,
                            );
                            verticalTabCallback(index, tabs[index].text);
                          },
                          child: Container(
                            decoration: BoxDecoration(
                              color: itemBGColor,
                            ),
                            child: Row(
                              crossAxisAlignment: CrossAxisAlignment.stretch,
                              children: <Widget>[
                                ScaleTransition(
                                  child: Container(
                                    width: (params.indicatorWidth != null)? params.indicatorWidth : cons.heightFive ,
                                    height: (params.itemExtent != null)? params.itemExtent : cons.heightHundred ,
                                    color: (params.indicatorColor != null)? params.indicatorColor: Theme.of(context).indicatorColor,
                                  ),
                                  scale: Tween(begin: cons.tweenValueBegin, end: cons.tweenValueEnd).animate(
                                    new CurvedAnimation(
                                      parent: animationControllers[index],
                                      curve: Curves.elasticOut,
                                    ),
                                  ),
                                ),
                                Expanded(
                                  child: Container(
                                    alignment: alignment,
                                    padding: EdgeInsets.all(cons.heightFive),
                                    child: child,
                                  ),
                                ),
                              ],
                            ),
                          ),
                        );
                      },
                    ),
                  ),
                  elevation: (params.tabsElevation != null)? params.tabsElevation : cons.heightTen,
                  shadowColor: (params.tabsShadowColor != null)? params.tabsShadowColor: mediumGreyThemeData().accentIconTheme.color,
                  shape: BeveledRectangleBorder(),
                ),
                Expanded(
                  child: PageView.builder(
                    scrollDirection: (params.contentScrollAxis != null)? params.contentScrollAxis : Axis.vertical,
                    physics: pageScrollPhysics,
                    onPageChanged: (index) {
                      if (_changePageByTapView == false ||
                          _changePageByTapView == null) {
                        _selectTab(index);
                      }
                      if (_selectedIndex == index) {
                        _changePageByTapView = null;
                      }
                      setState(() {});
                    },
                    controller: pageController,
                    // the number of pages
                    itemCount: widget.tabsInfo.length,
                    // building pages
                    itemBuilder: (BuildContext context, int index) {
                      return wid[index];
                    },
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
    }
    else{
    List<Tab> tabs = [];
    List<Widget> wid = [];
    List<ListItems> prodContainer = [];
    for (int tabCount = 0; tabCount < tabsInfo.length; tabCount++) {
      prodContainer.add(
          new ListItems(tabsInfo[tabCount].icons, tabsInfo[tabCount].text));
    }
    var tabx;
    for (var counter = 0; counter < tabsInfo.length; counter++) {
      tabx = new Tab(
          text: tabsInfo[counter].text,  
          icon: Icon(tabsInfo[counter].icons, color: Theme.of(context).indicatorColor) != null
              ? Icon(tabsInfo[counter].icons, color: Theme.of(context).indicatorColor)
              : Icon(Icons.favorite),
              );
      tabs.add(tabx);
    }
    for (var i = 0; i < tabsInfo.length; i++) {
      tabx = tabsInfo[i].widget;
      wid.add(tabx);
    }

    return Directionality(
      textDirection: TextDirection.ltr,
      child: Column(
        children: <Widget>[
          Expanded(
            child: Row(
              children: <Widget>[
                Material(
                  child: Container(
                    width: cons.heightHundred,
                    color: Theme.of(context).disabledColor ,
                    child: ListView.builder(
                      itemExtent: cons.heightHundred + cons.heightSixty,
                      itemCount: tabsInfo.length,
                      itemBuilder: (context, index) {
                        Tab tab = tabs[index];
                        Alignment alignment = Alignment.centerLeft;
                        Widget child;
                        if (tab.child != null) {
                          child = tab.child;
                        } else {
                          child = Row(
                            children: <Widget>[
                              (tab.icon != null)
                                  ? Row(
                                children: <Widget>[
                                  tab.icon,
                                  SizedBox(
                                    width: cons.heightFive,
                                  )
                                ],
                              )
                                  : Container(),
                              (tab.text != null) ? Text(tab.text) : Container(),
                            ],
                          );
                        }
                        Color itemBGColor = Theme.of(context).disabledColor ;
                        if (_selectedIndex == index)
                          itemBGColor = Theme.of(context).selectedRowColor;
                        return GestureDetector(
                          onTap: () {
                            
                            _changePageByTapView = true;
                            setState(() {
                              _selectTab(index);
                            });
                            
                            pageController.animateToPage(index,
                                duration: Duration(seconds: cons.intTwo),
                                curve: Curves.easeInOut,
                            );
                            verticalTabCallback(index, tabs[index].text);
                          },
                          child: Container(
                            decoration: BoxDecoration(
                              color: itemBGColor,
                            ),
                            child: Row(
                              crossAxisAlignment: CrossAxisAlignment.stretch,
                              children: <Widget>[
                                ScaleTransition(
                                  child: Container(
                                    width: cons.heightFive ,
                                    height: cons.heightHundred ,
                                    color: Theme.of(context).indicatorColor,
                                  ),
                                  scale: Tween(begin: cons.tweenValueBegin, end: cons.tweenValueEnd).animate(
                                    new CurvedAnimation(
                                      parent: animationControllers[index],
                                      curve: Curves.elasticOut,
                                    ),
                                  ),
                                ),
                                Expanded(
                                  child: Container(
                                    alignment: alignment,
                                    padding: EdgeInsets.all(cons.heightFive),
                                    child: child,
                                  ),
                                ),
                              ],
                            ),
                          ),
                        );
                      },
                    ),
                  ),
                  elevation: cons.heightTen,
                  shadowColor: Theme.of(context).primaryColorDark,
                  shape: BeveledRectangleBorder(),
                ),
                Expanded(
                  child: PageView.builder(
                    scrollDirection:  Axis.vertical,
                    physics: pageScrollPhysics,
                    onPageChanged: (index) {
                      if (_changePageByTapView == false ||
                          _changePageByTapView == null) {
                        _selectTab(index);
                      }
                      if (_selectedIndex == index) {
                        _changePageByTapView = null;
                      }
                      setState(() {});
                    },
                    controller: pageController,
                    // the number of pages
                    itemCount: widget.tabsInfo.length,
                    // building pages
                    itemBuilder: (BuildContext context, int index) {
                      return wid[index];
                    },
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
    }

  }
  void _selectTab(index) {
    _selectedIndex = index;
    for (AnimationController animationController in animationControllers) {
      animationController.reset();
    }
    animationControllers[index].forward();
  }
}

