import 'package:flutter/material.dart';
import 'consts.dart' ;
import 'widget-classesUsed.dart';


/*This widget is used to display a Grid View.
    The grid view comprises cards, that contain a header, a sub-widget, and a label.
    The individual cards can be tapped or long-pressed to perform certain functions.
    The user can also specify the cross axis count and the callback functions.

    imports:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-grid.dart';
import 'custom-icon.dart';


    SAMPLE IMPLEMENTATION:
    NetworkImage imageobj= new NetworkImage("http://images.unsplash.com/photo-1499084732479-de2c02d45fcc?ixlib=rb-1.2.1&ixid=eyJhcHBfaWQiOjEyMDd9&auto=format&fit=crop&w=889&q=80");
    Area Obj1 = new Area("Image Title", Image(image: imageobj),"The beautiful night");

    IconState icon1 =new IconState();
    Area Obj2 = new Area("Icon Title", customisedIcon(icon1), "Blue Umbrella Icon");
    List<Area> AreaList=[];
    AreaList.add(Obj1);
    AreaList.add(Obj2);

    onclickGrid(int nIndex, String sText) {
      print(nIndex);
      print(sText);
    }
    onLongPressGrid(int nIndex, String text1, String text2) {
      print(nIndex);
      print(text1);
      print(text2);
    }
    Grid gridobj=new Grid(count:2,callback:onclickGrid,longcallback:onLongPressGrid,crossaxisspacing:16.0,mainaxisspacing:16.0, cardColour:Colors.white, textColour:Colors.black);

      body: Center(child: customisedGridView(AreaList, gridobj))
    */

//AUTHOR : Soumyadeep Mitra

//WIDGET IMPLEMENTATION
Widget customisedGridView(List<Area> area, Grid gridobj) {
  return Container(
    child: new GridView.builder(
      itemCount: area.length,

      gridDelegate: new SliverGridDelegateWithFixedCrossAxisCount(
          crossAxisCount: gridobj.count==null?2:gridobj.count,
          crossAxisSpacing: gridobj.crossaxisspacing==null?16.0:gridobj.crossaxisspacing,
          mainAxisSpacing: gridobj.mainaxisspacing==null?16.0:gridobj.mainaxisspacing),
      itemBuilder: (BuildContext context, int index) {
        return InkWell(
          onTap: () {
            gridobj.callback(index, area[index].header);
          },
          onLongPress: () {
            gridobj.longcallback(index, area[index].header, area[index].label);
          },
          child: new Card(
            color: gridobj.cardColour==null?Theme.of(context).backgroundColor:gridobj.cardColour,
            child: Column(
              children: <Widget>[
                SizedBox(height: heightTen),
                new Center(
                    child: Text(
                      area[index].header,
                      style: TextStyle(
                          color: gridobj.textColour==null?Theme.of(context).primaryColorDark:gridobj.textColour,
                          fontSize: font_small,
                          fontWeight: FontWeight.bold),
                    )),
                Expanded(child: Container(child: area[index].widget)),
                new Center(
                  child: Text(area[index].label,style: TextStyle(
                      color: gridobj.textColour==null?Theme.of(context).primaryColorDark:gridobj.textColour,),),
                ),
                SizedBox(height: heightTen),
              ],
            ),
          ),
        );
      },
    ),
  );
}

