/*
Description:

A widget which generates a card consisting of an image and four text parameters.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-itemCard.dart';

Usage:

ItemCardParameters class is used to pass parameters such as the cardColor,box decoration and box shadow properties for the card and the image and four text objects.
imgType = 'Network' for a network imgPath & imgType='Asset' for an asset imgPath.
The flex parameter for the image and each text can be adjusted within the card.
A sample card with default properties is created if no parameters are defined.


- Defining the callback and item card objects

 MaterialCardData ItemCardObj = new MaterialCardData(
       imgType: 'Network',imgPath: 'https://images-na.ssl-images-amazon.com/images/I/51oHUvYzbsL._SX327_BO1,204,203,200_.jpg',
       containerHeight: 300,
       containerWidth: 250,
       cardbgColor: Colors.grey,footerText :'Review: 4.5/5',title: "The Theory of Everything",subtitle: 'Genre: Science, Cosmology.',bodyText: 'Publication Date 2002',imgHeight:80,imgWidth:100, );

- Object call for the widget


   CustomItemCard(ItemCardObj),


Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';
import 'theme.dart';

class CustomItemCard extends StatefulWidget {
 final MaterialCardData param;
  CustomItemCard(
      this.param);

  @override
  State<StatefulWidget> createState() {
    return _ItemCard(this.param);
  }
}

class _ItemCard extends State<CustomItemCard> {
  MaterialCardData param;
  _ItemCard(
      this.param);

  @override
  Widget build(BuildContext context) {
    if (param == null) {
      return customCard(defaultObj);
    } else {
      return customCard(this.param);
    }
  }

  Widget customCard(MaterialCardData param) {
    return Container(
        decoration: BoxDecoration(
          color: (param.cardbgColor != null)
              ? param.cardbgColor
              : Theme.of(context).primaryColor,
          border: Border.all(
              color: (param.borderColor != null)
                  ? param.borderColor
                  : Theme.of(context).textTheme.caption.color,
              width: (param.borderWidth != null)
                  ? widget.param.borderWidth
                  : cons.offset1),
          borderRadius: BorderRadius.all(Radius.circular(
              (param.borderRadius != null)
                  ? param.borderRadius
                  : cons.heightFive)),
          boxShadow: [
            (param.boxShadow != null) ? param.boxShadow : BoxShadow()
          ],
        ),
        padding: EdgeInsets.all(cons.heightFive),
        height: param.containerHeight != null
            ? param.containerHeight
            : cons.heightFourHundred,
        width: param.containerWidth != null
            ? param.containerWidth
            : cons.heightFourHundred,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: <Widget>[
            Expanded(
              flex: (param.imageFlex != null) ? param.imageFlex : cons.intFive,
              child: (param.imgType == cons.Network)
                  ? Image.network(
                      (param.imgPath != null) ? param.imgPath : "http://obdskopje.com.mk/assets/imgs/img_placeholder.png",
                      width: (param.imgWidth != null)
                          ? param.imgWidth
                          : cons.heightSeventy,
                      height: (param.imgHeight != null)
                          ? param.imgHeight
                          : cons.heightSeventy,
                    )
                  : Image.asset(
                (param.imgPath != null) ? param.imgPath : cons.assetImage,
                      width: (param.imgWidth != null)
                          ? param.imgWidth
                          : cons.heightSeventy,
                      height: (param.imgHeight != null)
                          ? param.imgHeight
                          : cons.heightSeventy,
                    ),
            ),
            Expanded(
              flex: (param.text1Flex != null) ? param.text1Flex : cons.intOne,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                mainAxisAlignment: MainAxisAlignment.start,
                children: <Widget>[
                  Text(
                    (param.title != null) ? param.title : cons.text1,
                    style: (param.textStyle1 != null)
                        ? param.textStyle1
                        : Theme.of(context).textTheme.bodyText1,
                    overflow: TextOverflow.ellipsis,
                  ),
                ],
              ),
            ),
            Expanded(
              flex: (param.text2Flex != null) ? param.text2Flex : cons.intOne,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                mainAxisAlignment: MainAxisAlignment.start,
                children: <Widget>[
                  Text(
                    (param.subtitle != null) ? param.subtitle : cons.text2,
                    style: (param.textStyle2 != null)
                        ? param.textStyle2
                        : Theme.of(context).textTheme.bodyText1,
                    overflow: TextOverflow.ellipsis,
                  )
                ],
              ),
            ),
            Expanded(
              flex: (param.text3Flex != null) ? param.text3Flex : cons.intOne,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                mainAxisAlignment: MainAxisAlignment.start,
                children: <Widget>[
                  Text(
                    (param.bodyText != null) ? param.bodyText : cons.text3,
                    style: (param.textStyle3 != null)
                        ? param.textStyle3
                        : Theme.of(context).textTheme.bodyText1,
                    overflow: TextOverflow.ellipsis,
                  ),
                ],
              ),
            ),
            Expanded(
              flex: (param.text4Flex != null) ? param.text4Flex : cons.intOne,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                mainAxisAlignment: MainAxisAlignment.start,
                children: <Widget>[
                  Text(
                    (param.footerText != null) ? param.footerText : cons.text4,
                    style: (param.textStyle4 != null)
                        ? param.textStyle4
                        : Theme.of(context).textTheme.bodyText2,
                    overflow: TextOverflow.ellipsis,
                  ),
                ],
              ),
            ),
          ],
        ));
  }
}

// ignore: missing_required_param
MaterialCardData defaultObj = new MaterialCardData(
  imgType: 'Asset',
  imgPath: 'images/logo.png',
  containerHeight: cons.heightThreeHundred,
  containerWidth: cons.heightTwoHundred,
  cardbgColor: mediumGreyThemeData().primaryColor,
  title: cons.text1,
  subtitle: cons.text2,
  bodyText: cons.text3,
  footerText: cons.text4,
  imgWidth: 70,
  imgHeight: 70,
  dividerColor: Colors.amberAccent,
  icon: Icon(cons.icon1), 
  btnColor: Colors.white, 
  btnGrpList1: <Widget>[],
  visibilityCardActionBar: true,
  btnGrpList2: null,
  btnText: "",
  btnTextColor: Colors.black, 
  btnTextOne: "", 
  btnTextTwo: "",
  btnViewone: "",
  btnViewthree: "",
  btnViewtwo: "",
  borderColor: Colors.black,
  borderRadius: cons.heightTen,
  borderWidth: cons.heightTwo,
  boxShadow: null,
  ratingBarColor: Colors.blue,
  cardOpacity: 0.5,
  containerbgColor: Colors.white10,
);
