/*
Description:
A widget that creates a custom TextField in which the user can input.

Usage:
The user can pass in  maximum length and obsecure property of the text field .
The user can also pass on parameters like box decoration, prefix icon, fill colour etc.
See CustomTextFieldParameters class definitons for more information.
The user also passes a callback function which is invoked when the TextField is used.
- The widget returns the entered text when submitted.

   onTextSubmit(String sText) {
      print(sText);
    }


    TextFieldParameters finalObj = new TextFieldParameters(
      maxLength: 10,
      obsecureText: false,
      maxLengthEnforced: true,
      decoration: InputDecoration(hintText: 'Password',labelText: 'Password',
        prefixIcon: Icon(Icons.lock),
        filled: true, fillColor: Colors.white,
        counterText: "",
        border: OutlineInputBorder(
            borderRadius: BorderRadius.circular(50.0),
            borderSide: BorderSide(
                color: Colors.black)),
      ),
      cursorColor: Colors.black,
      cursorWidth: 2,
      expands: false,
      maxLines: 1,
      readOnly: false,
      showCursor: true,
      style: TextStyle(color: Colors.blue),
    );


    CustomTextField( params: finalObj, callbackTextfield: onTextSubmit)

    Imports:
    import 'dart:ui';
    import 'package:flutter/material.dart';
    import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
    import 'custom-textField.dart';

Author:
Anubhav Sinha
*/


import 'dart:ui';
import 'package:flutter/material.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';



class CustomTextField extends StatefulWidget {

  final TextFieldParameters params;
  final void Function(String) callbackTextfield;

  const CustomTextField({
    Key key,

    this.params,
    this.callbackTextfield

  }) :
        super(key: key);
  @override
  _CustomTextFieldState createState() => _CustomTextFieldState(
      this.params,
      this.callbackTextfield
  );
}
class _CustomTextFieldState extends State<CustomTextField> {
  TextFieldParameters params;
  void Function(String) callbackTextfield;
  _CustomTextFieldState(
    this.params,
    this.callbackTextfield,
      );
  String change = '';
  final TextEditingController _textEditingControl = new TextEditingController();
  @override
  Widget build(BuildContext context) {
    if (params != null){
      return TextField(
        controller: _textEditingControl,
        maxLength: (params.maxLength != null)? params.maxLength : cons.MAX_Length,
        maxLengthEnforced: (params.maxLengthEnforced != null)? params.maxLengthEnforced : cons.MAX_Length_Enforced,
        obscureText: (params.obsecureText != null)? params.obsecureText : cons.OBSECURE_Text,
        cursorColor: (params.cursorColor != null)? params.cursorColor : Theme.of(context).primaryColorDark,
        //autofocus: true,
        decoration: (params.decoration != null)? params.decoration: InputDecoration(
          prefixIcon: Icon(Icons.add_alarm),
          filled: true,
          fillColor: Theme.of(context).focusColor,
          border: OutlineInputBorder(
              borderRadius: BorderRadius.circular(cons.padding_value2),
              borderSide: BorderSide(
                color: Theme.of(context).primaryColorDark,

              )
          ),
        ),
        style: (params.style != null)? params.style: TextStyle(color: Theme.of(context).primaryColorDark),
        onChanged: (String temp) {
          setState(() {
            change = temp;
          });
          //print(e);
        },

        onSubmitted: (String temp){
          setState(() {
            change= temp;
          });
          callbackTextfield(temp);
        },
        //onSubmitted: _submission,
      );
    }//if
    
    else{
      return TextField(
        controller: _textEditingControl,
        maxLength: cons.MAX_Length,
        maxLengthEnforced: cons.MAX_Length_Enforced,
        obscureText: cons.OBSECURE_Text,
        cursorColor: Theme.of(context).cursorColor,
        autofocus: false,
        decoration: InputDecoration(
          border: OutlineInputBorder(
              borderRadius: BorderRadius.circular(cons.padding_value2),
              borderSide: BorderSide(
                color: Theme.of(context).primaryColorDark,
              )
          ),
        ),
        style: TextStyle(color: Theme.of(context).primaryColorDark),
        onChanged: (String temp) {
          setState(() {
            change = temp;
          });
          //print(e);
        },
        onSubmitted: (String temp){
          setState(() {
            change= temp;
          });
          print(temp);
        },

      );
    }
  }
}


